@@ -129,7 +129,7 @@ class ModelPieces(ModelTemplate):
 
 class ModelThemes(ModelTemplate):
 
-    def __init__(self, path, binary_path):
+    def __init__(self, path, binary_path=None):
         super().__init__()
         self.model, self.binary = self.load_model(path, binary_path)
 
@@ -138,8 +138,11 @@ class ModelThemes(ModelTemplate):
         model_file = open(path, "rb").read()
         model = pickle.loads(model_file)
 
-        binary_model_file = open(binary_path, "rb").read()
-        binary_model = pickle.loads(binary_model_file)
+        if binary_path:
+            binary_model_file = open(binary_path, "rb").read()
+            binary_model = pickle.loads(binary_model_file)
+        else:
+            binary_model = None
 
         return model, binary_model
 
@@ -153,13 +156,13 @@ class ModelThemes(ModelTemplate):
         return emb
 
     def inference(self, process):
-        
+
         for i in range(len(process)):
             process[i] = ' '.join(process[i])
 
         process = [' '.join(process)]
 
-        inference = self.predict(process, binary=True)
+        inference = self.predict(process, binary=bool(self.binary))
         return inference
 
 
